@@ -17,7 +17,7 @@ class FileIO(ABC):
         subclass_map = {subclass.storage_type: subclass for subclass in cls.__subclasses__()}
 
         # Select the proper subclass based on
-        subclass = subclass_map[storage_type]
+        subclass = subclass_map[storage_type.lower()]
         instance = super(FileIO, subclass).__new__(subclass)
         return instance
     
