@@ -4,11 +4,16 @@ from .get_arguments import get_argument
 from datetime import datetime
 import requests
 
-class Http:
-    def __init__(self) -> None:
-        pass
+class Http(FileIO):
 
-    def download(self, remote_path, local_path, overwrite=True):
+    storage_type = os.path.basename(__file__).split('.py')[0]
+
+    def __init__(self, name=None) -> None:
+        self.name=name
+
+    def download(self, local_path, remote_path=None):
+        if remote_path is None:
+            remote_path = self.get_remote_path()
         get_response = requests.get(remote_path,stream=True)
         
         #original_file_name  = remote_path.split("/")[-1] # original name of the file. Ignored for now, but leave this for future needs
@@ -18,8 +23,7 @@ class Http:
                 if chunk: # filter out keep-alive new chunks
                     f.write(chunk)
 
-    
-    def upload(self, local_path, remote_path, overwrite=True):
+    def upload(self, local_path, remote_path=None):
         raise NotImplementedError
 
     def get_modification_time(self):
